@@ -56,13 +56,13 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
     [Session($1 ...)]
 
     >>> server.sessions[0].windows
-    [Window(@1 ...:..., Session($1 ...)]
+    [Window(@1 1:..., Session($1 ...)]
 
     >>> server.sessions[0].attached_window
-    Window(@1 ...:..., Session($1 ...)
+    Window(@1 1:..., Session($1 ...)
 
     >>> server.sessions[0].attached_pane
-    Pane(%1 Window(@1 ...:..., Session($1 ...)))
+    Pane(%1 Window(@1 1:..., Session($1 ...)))
 
     References
     ----------
